########################################################################
## This script generates newly infected cases with Weibull incubation
## periods, and then compare the actual number of Type I unreported 
## cases and those by our estimation under two different window sizes 
## T=6 or 7. The window sizes are set to match those reported in the
## literature when Weibull incubation periods were used. The number of 
## daily new cases are generated according to the following
## Case 1: N=1000	     
## Case 2: N~Runif[600,1200] 
## Case 3: N~Runif[400,1600] 
## Case 4: N~Runif[200,2000] 
##
## Version history: 
## Ver 1.0		By Donghui Yan	 	08/06/2020
########################################################################
C<-1; ##Case 1
##C<-2; ##Case 2
##C<-3; ##Case 3
##C<-4; ##Case 4

##Strings used in the plot or figure names
if(C==1) { pStr<-"(Ni = 1000)"; fStr<-"1000";}
if(C==2) { pStr<-"(Ni ~ [600,1200])"; fStr<-"600-1200";}
if(C==3) { pStr<-"(Ni ~ [400,1600])"; fStr<-"400-1600";}
if(C==4) { pStr<-"(Ni ~ [200,2000])"; fStr<-"200-2000";}

## Weibull distribution with mu=6.4 and SD=2.3
## (shape parameter k=3.03861, scale parameter lambda=7.16294)
## k=(sigma/mu)^(-1.086), lambda=mu/gamma(1+1/k)
T1<-6; T2<-7;
mu<-6.4; sigma<-2.3;
k<-(sigma/mu)^(-1.086);
lambda<-mu/gamma(1+1/k);

rmse6<-0; rmse7<-0;
for(jj in 1:100)
{
cnt<-matrix(0,1000,1);
daily<-matrix(0,200,1);
for(i in 1:100)
{
	##Number of new infected cases
	if(C==1) N<-1000;
	if(C==2) N<-sample(600:1200,1,replace=FALSE);
	if(C==3) N<-sample(400:1600,1,replace=FALSE);
	if(C==4) N<-sample(200:2000,1,replace=FALSE);
	daily[i]<-N;

	##To generate Weibull incubation period for each of N cases
	z<-rweibull(N, shape=k, scale=lambda);
	L<-max(round(z));
	for(j in 1:L)
	{
		tmp<-sum(floor(z)==j);
		cnt[i+j]<-cnt[i+j]+tmp;
	}	
}
reported<-matrix(0,200,1);
cumulated<-matrix(0,200,1);
missing6<-matrix(0,200,1);
missing7<-matrix(0,200,1);
for(ii in 1:110)
{
	cumulated[ii]<-sum(daily[1:ii]);
	reported[ii]<-sum(cnt[1:ii]);
	missing6[ii]<-sum(cnt[(ii+1):(ii+T1)]);
	missing7[ii]<-sum(cnt[(ii+1):(ii+T2)]);
}
TT<-100;
missing<-cumulated[1:TT]-reported[1:TT];
rmse6t<-abs(missing-missing6[1:TT])/reported[1:TT];
rmse6t<-mean(rmse6t[6:100]);
rmse6<-rmse6 + rmse6t;
rmse7t<-abs(missing-missing7[1:TT])/reported[1:TT];
rmse7t<-mean(rmse7t[7:100]);
rmse7<-rmse7 + rmse7t;

##The plot function only invoked once to produce various plots in the paper
if(jj==1){
ymax<-max(missing7,cumulated[1:TT]-reported[1:TT]);

postscript(file=paste("sensitivityW",fStr,".eps",sep=""),height=5, width=6.0);
plot(missing[1:TT],col="blue",type="b",ylim=c(0,ymax),
	pch=21,
	xlab=paste("Days since start ",pStr,sep=""),
	ylab="Missing case counts of type I");
points(1:TT,missing6[1:TT],col="red",type="b",pch=17);
points(1:TT,missing7[1:TT],col="red",type="b",pch=18);
##points(1:TT,daily[1:TT],col="black",type="b",pch=21,lty=2);
legend("bottomright", legend=c("Estimated (T=7)",
				"Unreported type I cases", "Estimated (T=6)"),
				pch=c(18,21,17), 
				col=c("red","blue","red"));
dev.off();
}
}##End of for(jj) loop
cat("Average rmse6=",rmse6/100, ", rmse7=", rmse7/100, "\n");
